aboutsummaryrefslogtreecommitdiffstats
path: root/OpenAL32/Include/alMain.h
diff options
context:
space:
mode:
Diffstat (limited to 'OpenAL32/Include/alMain.h')
-rw-r--r--OpenAL32/Include/alMain.h13
1 files changed, 2 insertions, 11 deletions
diff --git a/OpenAL32/Include/alMain.h b/OpenAL32/Include/alMain.h
index 439c0e3f..afc94da2 100644
--- a/OpenAL32/Include/alMain.h
+++ b/OpenAL32/Include/alMain.h
@@ -367,9 +367,8 @@ struct ALCdevice_struct
// Map of Filters for this device
UIntMap FilterMap;
- // Linked List of Databuffers for this device
- struct ALdatabuffer *DatabufferList;
- ALuint DatabufferCount;
+ // Map of Databuffers for this device
+ UIntMap DatabufferMap;
// Stereo-to-binaural filter
struct bs2b *Bs2b;
@@ -480,14 +479,6 @@ void al_print(const char *fname, unsigned int line, const char *fmt, ...)
PRINTF_STYLE(3,4);
#define AL_PRINT(...) al_print(__FILE__, __LINE__, __VA_ARGS__)
-#define DECL_VERIFIER(name, type, field) \
-static type* Verify##name(type *list, ALuint id) \
-{ \
- while(list && list->field != id) \
- list = list->next; \
- return list; \
-}
-
#ifdef __cplusplus
}
#endif